caellion-python-commons: caellion.pycommons.encoding.base36.InvalidCustomCharsetException Class Reference

caellion-python-commons

caellion.pycommons.encoding.base36.InvalidCustomCharsetException Class Reference

This exception is raised when more than exactly one instance of a given field is contained within field list. More...

Inheritance diagram for caellion.pycommons.encoding.base36.InvalidCustomCharsetException:

## Detailed Description

This exception is raised when more than exactly one instance of a given field is contained within field list.

Definition at line 14 of file base36.py.

The documentation for this class was generated from the following file:

- caellion/pycommons/encoding/base36.py